cloudcover-site-data 0.1.1

Static site data generator for CloudCover
docs.rs failed to build cloudcover-site-data-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.